@@ -21,7 +21,7 @@ import zope.app.form.browser
 import zc.resourcelibrary
 
 
-class FckeditorWidget(zope.app.form.browser.TextAreaWidget):
+class FckeditorWidget(zope.formlib.widgets.TextAreaWidget):
 
     editorWidth = 600
     editorHeight = 400
@@ -60,10 +60,10 @@ var oFCKeditor_%(shortname)s = new FCKeditor(
 </script>
 '''
 
-class CkeditorWidget(zope.app.form.browser.TextAreaWidget):
+class CkeditorWidget(zope.formlib.widgets.TextAreaWidget):
 
     editorHeight = 400
-    fckVersion = '3.2.1'
+    fckVersion = '3.6.2'
 
     configurationPath = "/@@/zope_ckconfig.js"
 
